Learn R Programming

enrichR (version 3.4)

.formatGenes: FormatGenes

Description

Given an input, check format and return a character vector

Usage

.formatGenes(x, type = c("standard", "background"))

Value

Character vector

Arguments

x

Vector or dataframe of genes with or without score

type

Depends on type of gene input

Author

I-Hsuan Lin [email protected]

Details

In standard analysis without background, crisp (symbols only) and fuzzy (with scores) gene sets are acceptable In analysis with background, only crisp gene sets are acceptable